<?php
// ------------------------------------------------------------------------- //
// IBDTraceur v1.0 - Fonctions de mise au point PHP                          //
// ------------------------------------------------------------------------- //
// Copyright (C) 2006  Matthieu SARTER <IBDTraceur@infobidouille.com>        //
//                     http://matthieu.sarter.fr/php                         //
//                     http://www.infobidouille.com                          //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //

if (!isset($_IBDTraceur)) {
    $_IBDTraceur["nbInstances"] = 0;
}

if (!defined("_IBDTraceur_")) {
    define("_IBDTraceur_", 1);
    /*
    * Classe IBDTraceur
    *
    * Cette classe fournit un ensemble de fonction destines  la mise au point
    * d'applications PHP.
    *
    */
    class IBDTraceur {
        var $module;
        var $limiteErreurs;
        var $limiteAlertes;
        var $niveauEcho;
        var $niveauEchoCommentaires;

        /* 
        * Constructeur de la classe
        *
        * @param module Le nom du module qui utilise cette instance du traceur
        * @param niveauEcho Valeur maximale du niveau d'un message affich dans la
        *        sortie HTML.
        *        Dfaut : O (Erreur)
        * @param niveauEchoCommentaires Valeur maximale du niveau d'un message
        *        affich sous forme de commentaire dans la sortie HTML.
        *        Dfaut : 1 (Alerte)
        * @param limiteErreur Nombre maximum d'erreur dans ce module avant de
        *        forcer l'arrt du script.
        * @param limiteErreur Nombre maximum d'alertes dans ce module avant de
        *        forcer l'arrt du script.
        */
        function IBDTraceur($module, $niveauEcho = 0, $niveauEchoCommentaires = 1, $limiteErreurs = 5, $limiteAlertes = 50) {
            global $_IBDTraceur;
            $this->module = $module;
            $this->niveauEcho = $niveauEcho;
            $this->niveauEchoCommentaires = $niveauEchoCommentaires;
            $this->limiteErreurs = $limiteErreurs;
            $this->limiteAlertes = $limiteAlertes;
            if (!isset($_IBDTraceur[$this->module])) {
                $_IBDTraceur[$this->module]["nbErreurs"] = 0;
                $_IBDTraceur[$this->module]["nbAlertes"] = 0;
            }
            if (!isset($_IBDTraceur["nbErreurs"])) {
                $_IBDTraceur["nbErreurs"] = 0;
            }
            if (!isset($_IBDTraceur["nbAlertes"])) {
                $_IBDTraceur["nbAlertes"] = 0;
            }
            $_IBDTraceur["nbInstances"]++;
        }

        /*
        * Affiche un message d'erreur.
        *
        * @param message Message d'erreur  afficher.
        * @param fonction Nom de la fonction source de l'erreur.
        */
        function tracerErreur($message, $fonction = "") {
            global $_IBDTraceur;
            $_IBDTraceur[$this->module]["nbErreurs"]++;
            $_IBDTraceur["nbErreurs"]++;
            $this->tracer(0, $message, $fonction);
            if ($_IBDTraceur[$this->module]["nbErreurs"] > $this->limiteErreurs) {
                $this->tracer(0, "Nombre maximal d'erreurs atteint", $fonction);
                die();
            }
        }

        /*
        * Affiche un message d'alerte.
        *
        * @param message Message d'erreur  afficher.
        * @param fonction Nom de la fonction source de l'alerte.
        */
        function tracerAlerte($message, $fonction = "") {
            global $_IBDTraceur;
            $_IBDTraceur[$this->module]["nbAlertes"]++;
            $_IBDTraceur["nbAlertes"]++;
            $this->tracer(1, $message, $fonction);
            if ($_IBDTraceur[$this->module]["nbAlertes"] > $this->limiteAlertes) {
                $this->tracer(0, "Nombre maximal d'alertes atteint", $fonction);
                die();
            }
        }

        /*
        * Affiche un message.
        *
        * @param message Message  afficher.
        * @param fonction Nom de la fonction source du message.
        */
        function tracer($niveau, $message, $fonction = "main", $type = "") {
            global $_IBDTraceur;
            if ($niveau == 0) {
                $type = "<font color=\"red\">ERREUR</font>@";
            }
            else if ($niveau == 1) {
                $type = "ALERTE@";
            }
            if ($niveau <= $this->niveauEcho) {
                echo("<br /><nobr>
    <b>".$type.$this->module.".".$fonction." :</b> ".$message."
    </nobr><br />");
            }
            else if ($niveau <= $this->niveauEchoCommentaires) {
                echo("<!--
    ".$type.$this->module.".".$fonction." : ".$message."
    -->");
            }
        }

        /*
        * Incrmente le compteur d'appels d'une fonction.
        *
        * @param fonction Nom de la fonction.
        */
        function incrementerAppels($fonction) {
            global $_IBDTraceur;
            if (!isset($_IBDTraceur[$this->module]["nbAppels.".$fonction])) {
                $_IBDTraceur[$this->module]["nbAppels.".$fonction] = 1;
            }
            else {
                $_IBDTraceur[$this->module]["nbAppels.".$fonction]++;
            }
        }

        /*
        * Rcupre la valeur du compteur d'appels d'une fonction.
        *
        * @param fonction Nom de la fonction.
        * @return La valeur courante du compteur d'appels.
        */
        function recupererAppels($fonction) {
            global $_IBDTraceur;
            if (isset($_IBDTraceur[$this->module]["nbAppels.".$fonction])) {
                return $_IBDTraceur[$this->module]["nbAppels.".$fonction];
            }
            return 0;
        }

        /*
        * Rcupre le nombre d'erreurs.
        *
        * @param global Si  1, rcupre le compteur global, sinon celui du module
        *        courant. Dfaut : 0.
        * @return La valeur courante du compteur d'erreurs.
        */
        function recupererNombreErreurs($global = 0) {
            global $_IBDTraceur;
            if ($global == 1) {
                return $_IBDTraceur[$this->module]["nbErreurs"];
            }
            return $_IBDTraceur["nbErreurs"];
        }

        /*
        * Rcupre le nombre d'alertes.
        *
        * @param global Si  1, rcupre le compteur global, sinon celui du module
        *        courant. Dfaut : 0.
        * @return La valeur courante du compteur d'alertes.
        */
        function recupererNombreAlertes($global = 0) {
            global $_IBDTraceur;
            if ($global == 1) {
                return $_IBDTraceur[$this->module]["nbAlertes"];
            }
            return $_IBDTraceur["nbAlertes"];
        }

        /*
        * Rcupre l'ensemble des informations stockes par le traceur.
        *
        * @param global Si  1, rcupre les informations globales, sinon celles du
        *        module courant. Dfaut : 0.
        * @param html Si  1, renvoie les informations formattes en HTML.
        *        Dfaut : 1.
        * @return Les informations mises " plat".
        */
        function recupererInformations($global = 0, $html = 1) {
            global $_IBDTraceur;
            include_once("ibd.lib.php");
            if ($global == 1) {
                $tableau = $_IBDTraceur;
            }
            else {
                $tableau = $_IBDTraceur[$this->module];
            }
            ksort($tableau);
            if ($html == 1) {
                return aplatirTableau($tableau, "<br />\r\n", "&nbsp;&nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;&nbsp;");
            }
            return aplatirTableau($tableau);
        }
    }
}
?>